# Changelog

All notable changes to this project will be documented in this file.

## 0.0.2 - (2025-03-10)

- Update project metadata.
- Add Python 3.8 as supported.

## 0.0.1 - (2025-03-05)

- Initial version.
